@@ -105,6 +105,7 @@ struct config_info {
 	time_t maxTime;
 	char * title;
 	char * ip2user;
+	char * sitefilter;
 	int sortcolumns;
 	unsigned int locationStats;
     unsigned int siteStats;
@@ -163,4 +164,9 @@ struct ip2user_line {
 	char *username;
 };
 
+struct exclude_netblock {
+	in_addr network;
+	in_addr netmask;
+};
+
 #endif
