@@ -74,6 +74,7 @@ bool do_configuration(int argc, char **argv) {
 	char *groupbyf = NULL;
 	char *groupbynetf = NULL;
 	char *ip2userf = NULL;
+	char *sitefilterf = NULL;
 	char *resourcedirf = NULL;
 	int debugf = 0;
     int sitereportf = 0;
@@ -115,6 +116,7 @@ bool do_configuration(int argc, char **argv) {
 		{"show_rates", TYPE_BOOL|TYPE_NULL, &srg.showrates},
 		{"nonameexists_showip", TYPE_BOOL|TYPE_NULL, &srg.nonameshowip},
 		{"iptouser_file", TYPE_STR|TYPE_NULL, &ip2userf},
+		{"destinationsitefilter_file", TYPE_STR|TYPE_NULL, &sitefilterf},
 		{"dontshow_onlydeniedusers", TYPE_BOOL|TYPE_NULL, &srg.hideDeniedOnly},
 		{"php_authentication", TYPE_BOOL|TYPE_NULL, &authf},
 		{"max_age", TYPE_INT|TYPE_NULL, &maxagef},
@@ -296,6 +298,14 @@ bool do_configuration(int argc, char **argv) {
 		srg.ip2user = strdup(ip2userf);
 	}
 	free(ip2userf);
+
+	if (sitefilterf != NULL) {
+		if (srg.debug)
+			fprintf(stderr, "Setting destination site filter file to %s "
+					"from config file\n", sitefilterf);
+		srg.sitefilter = strdup(sitefilterf);
+	}
+	free(sitefilterf);
 	
     if (sitereportf > 0) {
         if (srg.debug)
